@@ -10,7 +10,6 @@ require 'rbox_gui_edit_network.pl';
 require 'rbox_gui_edit_ioports.pl';
 require 'rbox_gui_edit_usb.pl';
 require 'rbox_gui_edit_shared.pl';
-require 'rbox_gui_edit_eval.pl';
 our (%gui, %vmc);
 
 sub show_dialog_edit {
@@ -46,6 +45,7 @@ sub show_dialog_edit {
         my $sysaccel = $gui{notebookEditSys}->get_nth_page(3);
         my $sysbootpage = $gui{notebookEditSys}->get_nth_page(4);
         my $dispvideopage = $gui{notebookEditDisp}->get_nth_page(0);
+        my $encryptionpage = $gui{notebookEditGen}->get_nth_page(3);
 
         if ($vmc{SessionType} eq 'WriteLock') {
             $gui{dialogEdit}->set_title("Edit Settings - $$gref{Name}");
@@ -66,6 +66,7 @@ sub show_dialog_edit {
             $sysadvanced->set_sensitive(1);
             $sysaccel->set_sensitive(1);
             $sysbootpage->set_sensitive(1);
+            $encryptionpage->set_sensitive(1);
             $gui{hscaleEditSysProcessor}->set_sensitive(1);
             $gui{checkbuttonEditSysPAE}->set_sensitive(1);
             $gui{checkbuttonEditSysCPUHotPlug}->set_sensitive(1);
@@ -94,6 +95,7 @@ sub show_dialog_edit {
             $sysadvanced->set_sensitive(0);
             $sysaccel->set_sensitive(0);
             $sysbootpage->set_sensitive(0);
+            $encryptionpage->set_sensitive(0);
             $gui{hscaleEditSysProcessor}->set_sensitive(0);
             $gui{checkbuttonEditSysPAE}->set_sensitive(0);
             $gui{checkbuttonEditSysCPUHotPlug}->set_sensitive(0);
@@ -117,6 +119,42 @@ sub show_dialog_edit {
         $gui{dialogEdit}->hide;
 
         if ($response eq 'ok') {
+            # We will apply encryption settings here as it's not possible to
+            # do it in real time
+            if ($gui{checkbuttonEditGenEncryption}->get_state()) {
+                my $cipher = &getsel_combo($gui{comboboxEditGenEncryptionCipher}, 0);
+                if ($cipher ne 'Unchanged') {
+
+                    my $passwd1 = $gui{entryEditGenEncryptionPass}->get_text();
+                    my $passwd2 = $gui{entryEditGenEncryptionPassCon}->get_text();
+
+                    if ($passwd1) {
+                        if ($passwd1 ne $passwd2) { &show_err_msg('encdiskpasswd'); }
+                        else {
+                            my @IMediumAttachment = IMachine_getMediumAttachments($vmc{IMachine});
+                            my %used_key_ids; # So we only ask for a Key ID once
+
+                            foreach my $attach (@IMediumAttachment) {
+                                next if ($$attach{type} ne 'HardDisk');
+
+                                if (&imedium_has_property($$attach{medium}, 'CRYPT/KeyStore')) {
+                                    # Disk is already encryped, so see if we can re-encrypt it
+                                    my $keyid = IMedium_getProperty($$attach{medium}, 'CRYPT/KeyId');
+
+                                    if (!$used_key_ids{$keyid}) {
+                                        my $npasswd = &show_dialog_decpasswd($$attach{medium}, $keyid);
+                                        &encrypt_disk($$attach{medium}, $npasswd, $cipher, $passwd1, $vmc{Name}) if ($npasswd);
+                                        $used_key_ids{$keyid} = $npasswd;
+                                    }
+                                }
+                                else {
+                                    &encrypt_disk($$attach{medium}, '', $cipher, $passwd1, $vmc{Name});
+                                }
+                            }
+                        }
+                    }
+                }
+            }
             IMachine_saveSettings($vmc{IMachine});
             &fill_list_guest();
             &addrow_log("Saved all settings for $$gref{Name}.");
