@@ -13,10 +13,8 @@ sub setup_edit_dialog_audio {
     $gui{comboboxEditAudioCodec}->signal_handler_block($signal{audiocodec});
     $gui{checkbuttonEditAudioEnable}->set_active(&bl(IAudioAdapter_getEnabled($vmc{IAudioAdapter})));
     $gui{tableEditAudio}->set_sensitive($gui{checkbuttonEditAudioEnable}->get_active()); # Ghost/Unghost other widgets based on audio enabled
-
-    # Enabling/Disabling Audio Inputs & Outputs seems broken in the API (test: 5.0.20)
-    #$gui{checkbuttonEditAudioIn}->set_active(&bl(IAudioAdapter_getEnabledIn($vmc{IAudioAdapter})));
-    #$gui{checkbuttonEditAudioOut}->set_active(&bl(IAudioAdapter_getEnabledOut($vmc{IAudioAdapter})));
+    $gui{checkbuttonEditAudioIn}->set_active(&bl(IAudioAdapter_getEnabledIn($vmc{IAudioAdapter})));
+    $gui{checkbuttonEditAudioOut}->set_active(&bl(IAudioAdapter_getEnabledOut($vmc{IAudioAdapter})));
 
     # Set WinMM and MMPM to Null as they no longer seem supported and cause problems if set.
     my $AudioDriver = IAudioAdapter_getAudioDriver($vmc{IAudioAdapter});
@@ -49,23 +47,21 @@ sub audio_toggle {
     }
 }
 
-# Enabling/Disabling Audio Inputs & Outputs seems broken in the API (test: 5.0.20)
 # Toggle whether audio inputs are enabled
-#sub audio_input_toggle {
-#    if ($vmc{SessionType} eq 'WriteLock') {
-#        my $state = $gui{checkbuttonEditAudioIn}->get_active();
-#        IAudioAdapter_setEnabledIn($vmc{IAudioAdapter}, $state);
-#    }
-#}
+sub audio_input_toggle {
+    if ($vmc{SessionType} eq 'WriteLock') {
+        my $state = $gui{checkbuttonEditAudioIn}->get_active();
+        IAudioAdapter_setEnabledIn($vmc{IAudioAdapter}, $state);
+    }
+}
 
-# Enabling/Disabling Audio Inputs & Outputs seems broken in the API (test: 5.0.20)
 # Toggle whether audio outputs are enabled
-#sub audio_output_toggle {
-#    if ($vmc{SessionType} eq 'WriteLock') {
-#        my $state = $gui{checkbuttonEditAudioOut}->get_active();
-#        IAudioAdapter_setEnabledOut($vmc{IAudioAdapter}, $state);
-#    }
-#}
+sub audio_output_toggle {
+    if ($vmc{SessionType} eq 'WriteLock') {
+        my $state = $gui{checkbuttonEditAudioOut}->get_active();
+        IAudioAdapter_setEnabledOut($vmc{IAudioAdapter}, $state);
+    }
+}
 
 # Set the audio controller type
 sub audio_ctr {
