@@ -13,7 +13,7 @@ sub setup_edit_dialog_storage {
     $gui{menuAttachDVD} = Gtk2::Menu->new();
     $gui{menuAttachFloppy} = Gtk2::Menu->new();
     $gui{menuitemAttachHD} = Gtk2::MenuItem->new_with_label('Hard Disks');
-    $gui{menuitemAttachDVD} = Gtk2::MenuItem->new_with_label('CDs/DVDs');
+    $gui{menuitemAttachDVD} = Gtk2::MenuItem->new_with_label('Optical Discs');
     $gui{menuitemAttachFloppy} = Gtk2::MenuItem->new_with_label('Floppy Disks');
     $gui{menuitemAttachHD}->set_submenu($gui{menuAttachHD});
     $gui{menuitemAttachDVD}->set_submenu($gui{menuAttachDVD});
@@ -175,23 +175,25 @@ sub sens_createhdformat {
 sub storage_ctr_add {
     my ($widget) = @_;
     my $bus = 'Floppy'; # Assume floppy unless set otherwise
+    my $ctrname = '';
 
     if ($widget eq $gui{menuitemCtrAddIDE}) { $bus = 'IDE'; }
     elsif ($widget eq $gui{menuitemCtrAddSCSI}) { $bus = 'SCSI'; }
     elsif ($widget eq $gui{menuitemCtrAddSATA}) { $bus = 'SATA'; }
     elsif ($widget eq $gui{menuitemCtrAddSAS}) { $bus = 'SAS'; }
     elsif ($widget eq $gui{menuitemCtrAddUSB}) { $bus = 'USB'; }
+    elsif ($widget eq $gui{menuitemCtrAddNVMe}) { $bus = 'PCIe'; }
 
     my @Controllers = IMachine_getStorageControllers($vmc{IMachine});
     my $exists = 0;
 
+    if ($bus eq 'PCIe') { $ctrname = 'NVMe'; }
+    else { $ctrname = $bus; }
+
     foreach my $ctr (@Controllers) { $exists = 1 if (IStorageController_getBus($ctr) eq $bus) }
 
     if (!$exists) {
-        my $IStorageController = IMachine_addStorageController($vmc{IMachine}, "$bus Controller", $bus);
-        # This works around the controller type defaults defaulting to USB. VB itself doesn't seem to use it.
-        if ($bus eq 'SAS') { IStorageController_setControllerType($IStorageController, 'LsiLogicSas', 0); }
-
+        my $IStorageController = IMachine_addStorageController($vmc{IMachine}, $ctrname, $bus);
         IStorageController_setPortCount($IStorageController, IStorageController_getMinPortCount($IStorageController)); # Controllers have all ports on by default. Set to the minimum
         &fill_list_editstorage($vmc{IMachine});
     }
@@ -333,6 +335,18 @@ sub storage_livecd {
     IMachine_temporaryEjectDevice($vmc{IMachine}, $$storref{ControllerName}, $$storref{Port}, $$storref{Device}, $gui{checkbuttonEditStorLive}->get_active());
 }
 
+# Flags whether a HD or Optical Device is hot pluggable
+sub storage_hot_pluggable {
+    my $storref = &getsel_list_editstorage();
+    IMachine_setHotPluggableForDevice($vmc{IMachine}, $$storref{ControllerName}, $$storref{Port}, $$storref{Device}, $gui{checkbuttonEditStorHotPluggable}->get_active());
+}
+
+# Flags whether the selected controller is bootable or not
+sub storage_controller_bootable {
+    my $storref = &getsel_list_editstorage();
+    IMachine_setStorageControllerBootable($vmc{IMachine}, $$storref{ControllerName}, $gui{checkbuttonEditStorControllerBootable}->get_active());
+}
+
 # Moves an attachment to a new port
 sub storage_connected_port {
     my $newdevice = &getsel_combo($gui{comboboxEditStorDevPort}, 1);
@@ -351,11 +365,12 @@ sub storage_connected_port {
         }
 
         if ($free) {
-            # At the moment, only SATA support creating actual ports
-            if (IStorageController_getPortCount($$storref{IStorageController}) < ($newport + 1) and $$storref{Bus} eq 'SATA') {
+            # SATA, SAS, NVMe support changing the ports
+            if ($$storref{Bus} eq 'SATA' or $$storref{Bus} eq 'SAS' or $$storref{Bus} eq 'PCIe') {
+            if (IStorageController_getPortCount($$storref{IStorageController}) < ($newport + 1)) {
                 IStorageController_setPortCount($$storref{IStorageController}, $newport + 1) ;
             }
-
+            }
             IMachine_detachDevice($vmc{IMachine}, $$storref{ControllerName}, $$storref{Port}, $$storref{Device});
             IMachine_attachDevice($vmc{IMachine}, $$storref{ControllerName}, $newport, $newdevice, $$storref{MediumType}, $$storref{IMedium});
             IMachine_saveSettings($vmc{IMachine});
@@ -365,91 +380,6 @@ sub storage_connected_port {
     }
 }
 
-# Handles the sensitive if a SATA controller is selected
-sub sens_editstor_sata_ctr {
-    $gui{labelEditStorPortCount}->show();
-    $gui{spinbuttonEditStorPortCount}->show();
-    $gui{menuitemAttachHD}->set_sensitive(1);
-    $gui{menuitemAttachDVD}->set_sensitive(1);
-    $gui{menuitemAttachFloppy}->set_sensitive(0);
-}
-
-sub sens_editstor_ctr {
-    $gui{menuitemAttachHD}->set_sensitive(1);
-    $gui{menuitemAttachDVD}->set_sensitive(1);
-    $gui{menuitemAttachFloppy}->set_sensitive(0);
-}
-
-sub sens_editstor_floppy_ctr {
-    $gui{menuitemAttachHD}->set_sensitive(0);
-    $gui{menuitemAttachDVD}->set_sensitive(0);
-    $gui{menuitemAttachFloppy}->set_sensitive(1);
-}
-
-sub sens_editstor_allctr {
-    $gui{frameEditStorAttr}->show();
-    $gui{buttonEditStorAddAttach}->set_sensitive(1);
-    $gui{buttonEditStorRemoveAttach}->set_sensitive(0);
-    $gui{buttonEditStorRemoveCtr}->set_sensitive(1);
-    $gui{labelEditStorCtrName}->show();
-    $gui{entryEditStorCtrName}->show();
-    $gui{labelEditStorCtrType}->show();
-    $gui{comboboxEditStorCtrType}->show();
-    $gui{checkbuttonEditStorCache}->show();
-    $gui{labelEditStorDevPort}->hide();
-    $gui{comboboxEditStorDevPort}->hide();
-    $gui{checkbuttonEditStorSSD}->hide();
-    $gui{checkbuttonEditStorLive}->hide();
-    $gui{labelEditStorPortCount}->hide();
-    $gui{spinbuttonEditStorPortCount}->hide();
-}
-
-# Handle widget sensitivity specify to HD media selection
-sub sens_editstor_hd {
-    $gui{buttonEditStorAddAttach}->set_sensitive(0);
-    $gui{checkbuttonEditStorSSD}->show();
-    $gui{checkbuttonEditStorLive}->hide();
-    $gui{menuitemAttachHD}->set_sensitive(1);
-    $gui{menuitemAttachDVD}->set_sensitive(0);
-    $gui{menuitemAttachFloppy}->set_sensitive(0);
-}
-
-# Handle widget sensitivity specify to DVD media selection
-sub sens_editstor_dvd {
-    $gui{buttonEditStorAddAttach}->set_sensitive(1);
-    $gui{checkbuttonEditStorSSD}->hide();
-    $gui{checkbuttonEditStorLive}->show();
-    $gui{menuitemAttachHD}->set_sensitive(0);
-    $gui{menuitemAttachDVD}->set_sensitive(1);
-    $gui{menuitemAttachFloppy}->set_sensitive(0);
-}
-
-# Handle widget sensitivity specify to floppy media selection
-sub sens_editstor_floppy {
-    $gui{buttonEditStorAddAttach}->set_sensitive(1);
-    $gui{checkbuttonEditStorSSD}->hide();
-    $gui{checkbuttonEditStorLive}->hide();
-    $gui{menuitemAttachHD}->set_sensitive(0);
-    $gui{menuitemAttachDVD}->set_sensitive(0);
-    $gui{menuitemAttachFloppy}->set_sensitive(1);
-}
-
-# Handle widget sensitivity common to all media selection
-sub sens_editstor_allmedia {
-    $gui{frameEditStorAttr}->show();
-    $gui{buttonEditStorRemoveAttach}->set_sensitive(1);
-    $gui{buttonEditStorRemoveCtr}->set_sensitive(0);
-    $gui{labelEditStorCtrName}->hide();
-    $gui{entryEditStorCtrName}->hide();
-    $gui{labelEditStorCtrType}->hide();
-    $gui{comboboxEditStorCtrType}->hide();
-    $gui{checkbuttonEditStorCache}->hide();
-    $gui{labelEditStorDevPort}->show();
-    $gui{comboboxEditStorDevPort}->show();
-    $gui{labelEditStorPortCount}->hide();
-    $gui{spinbuttonEditStorPortCount}->hide();
-}
-
 # Sets the sensitive of widgets if no storage item is selected
 sub sens_editstor_nosel {
     $gui{frameEditStorAttr}->hide(); # Hides all the attributed widgets in one go
