@@ -3,7 +3,7 @@ use strict;
 use warnings;
 our (%gui, %vmc, %signal);
 
-sub setup_edit_dialog_usb() {
+sub setup_edit_dialog_usb {
     # Valid USB States
     # O=0 E=0 X=0 : USB Disabled
     # O=1 E=0 X=0 : USB Enabled. Version 1.1
@@ -44,7 +44,7 @@ sub setup_edit_dialog_usb() {
     &addrow_log('USB settings complete.');
 }
 
-sub show_dialog_usbfilter() {
+sub show_dialog_usbfilter {
     my $filref = &getsel_list_usbfilters;
     $gui{entryUSBFilterName}->set_text(IUSBDeviceFilter_getName($$filref{IUSBDeviceFilter}));
     $gui{entryUSBFilterVendorID}->set_text(IUSBDeviceFilter_getVendorId($$filref{IUSBDeviceFilter}));
@@ -96,7 +96,7 @@ sub show_dialog_usbfilter() {
 
 # Toggles whether USB is enabled or not. Sub is unusual because VB uses the OHCI
 # controller to determine if USB is on or not.
-sub usb_toggle() {
+sub usb_toggle {
 
     my $state = $gui{checkbuttonEditUSBEnable}->get_active();
     if ($state) { IMachine_addUSBController($vmc{IMachine}, 'OHCI', 'OHCI'); }
@@ -114,7 +114,7 @@ sub usb_toggle() {
 # Handles setting the controller type. The sub is somewhat unusual because of the
 # way that VB uses OHCI as a toggle for USB being on/off and the awkward nature
 # in adding & removing controllers by name.
-sub usb_set_ctr_type() {
+sub usb_set_ctr_type {
     my ($widget) = @_;
     my @IUSBController = IMachine_getUSBControllers($vmc{IMachine});
 
@@ -135,7 +135,7 @@ sub usb_set_ctr_type() {
 }
 
 
-sub usb_addzerofilter() {
+sub usb_addzerofilter {
     my $filref = &getsel_list_usbfilters();
     my $pos = 0;
 
@@ -147,7 +147,7 @@ sub usb_addzerofilter() {
     &fill_list_usbfilters($vmc{IMachine});
 }
 
-sub usb_addfilter() {
+sub usb_addfilter {
     my ($widget, $usbid) = @_;
     my $filref = &getsel_list_usbfilters();
     my $pos = 0;
@@ -175,7 +175,7 @@ sub usb_addfilter() {
     return 0;
 }
 
-sub usb_makelabel() {
+sub usb_makelabel {
     my ($manu, $prod, $rev) = @_;
     my $label;
     $label = "$manu " if ($manu);
@@ -184,13 +184,13 @@ sub usb_makelabel() {
     return $label;
 }
 
-sub usb_removefilter() {
+sub usb_removefilter {
     my $filref = &getsel_list_usbfilters();
     IUSBDeviceFilters_removeDeviceFilter($vmc{USBFilters}, $$filref{Position});
     &fill_list_usbfilters($vmc{IMachine});
 }
 
-sub usb_movefilter() {
+sub usb_movefilter {
     my ($widget) = @_;
     my $pos = 0;
     my $filref = &getsel_list_usbfilters();
@@ -204,7 +204,7 @@ sub usb_movefilter() {
 }
 
 # Can't use getsel_list_usbfilters in here due to the way the signals are propagated
-sub usb_togglefilter() {
+sub usb_togglefilter {
     my ($widget, $path_str, $model) = @_;
     my $iter = $model->get_iter(Gtk2::TreePath->new_from_string($path_str));
     my $val = $model->get($iter, 0);
@@ -213,14 +213,14 @@ sub usb_togglefilter() {
     &fill_list_usbfilters($vmc{IMachine});
 }
 
-sub show_usb_menu() {
+sub show_usb_menu {
     my ($widget, $event) = @_;
     $gui{menuUSB}->popup(undef, undef, undef, undef, 0, $event->time) if ($event->button == 1);
     return 0;
 }
 
 # Sets the sensitivity depending on whether USB is enabled or not
-sub sens_usb_enabled() {
+sub sens_usb_enabled {
     my ($state) = @_;
 
     if ($state == 0) {
@@ -241,4 +241,4 @@ sub sens_usb_enabled() {
     elsif ($state == 3) { $gui{radiobuttonEditUSB3}->set_active(1); }
 }
 
-1;
\ No newline at end of file
+1;
