@@ -279,6 +279,7 @@ sub show_bioslogofilechooser {
                                     handler   => \&handle_bioslogofilechooser});
 }
 
+
 # Sets up the file chooser for selecting the video file directory
 sub show_videofilechooser {
     my ($vol, $dir, $file) = &rsplitpath($gui{entryEditDispCapturePath}->get_text());
@@ -304,74 +305,101 @@ sub show_exportapplfilechooser {
 }
 
 # Sets up the file chooser for selecting the appliance
-sub show_importapplfilechooser {
-    &show_remotefilechooser_window({title     => "Choose OVF/OVA file on $endpoint",
-                                    basedir   => $gui{entryVBPrefsGenMachineFolder}->get_text(),
-                                    filename  => '',
-                                    mode      => 'file',
-                                    filter    => '^.*\.ov[a|f]$', # To only show ova/ovf files
-                                    handler   => \&handle_importapplfilechooser});
+{
+    my $startloc = $gui{entryVBPrefsGenMachineFolder}->get_text();
+
+    sub show_importapplfilechooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose OVF/OVA file on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'file',
+                                                    filter    => '^.*\.ov[a|f]$', # To only show ova/ovf files
+                                                    handler   => \&handle_importapplfilechooser});
+    }
 }
 
 # Sets up the file chooser for selecting a VBOX file
-sub show_vboxfilechooser {
-    &show_remotefilechooser_window({title     => "Choose guest to add on $endpoint",
-                                    basedir   => $gui{entryVBPrefsGenMachineFolder}->get_text(),
-                                    filename  => '',
-                                    mode      => 'file',
-                                    filter    => '^.*\.vbox$', # To only show vbox files
-                                    handler   => \&handle_vboxfilechooser});
+{
+    my $startloc = $gui{entryVBPrefsGenMachineFolder}->get_text();
+
+    sub show_vboxfilechooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose guest to add on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'file',
+                                                    filter    => '^.*\.vbox$', # To only show vbox files
+                                                    handler   => \&handle_vboxfilechooser});
+    }
 }
 
 # Sets up the file chooser for selecting a medium (or any file actually)
-sub show_vmmfilechooser {
-    &show_remotefilechooser_window({title     => "Choose Media Images on $endpoint",
-                                    basedir   => $gui{entryVBPrefsGenMachineFolder}->get_text(),
-                                    filename  => '',
-                                    mode      => 'multifile',
-                                    filter    => '.*', # Allow any file
-                                    handler   => \&vmm_add});
+{
+    my $startloc = $gui{entryVBPrefsGenMachineFolder}->get_text();
+
+    sub show_vmmfilechooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose Media Images on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'multifile',
+                                                    filter    => '.*', # Allow any file
+                                                    handler   => \&vmm_add});
+    }
 }
 
 # Sets up the file chooser for selecting the default machine directory
-sub show_machinefolderchooser {
-    &show_remotefilechooser_window({title     => "Choose Machine Folder on $endpoint",
-                                    basedir   => $gui{entryVBPrefsGenMachineFolder}->get_text(),
-                                    filename  => '',
-                                    mode      => 'dir',
-                                    filter    => ' ^', # To only show directories
-                                    handler   => \&handle_machinefolderchooser});
+{
+    my $startloc = $gui{entryVBPrefsGenMachineFolder}->get_text();
+
+    sub show_machinefolderchooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose Machine Folder on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'dir',
+                                                    filter    => ' ^', # To only show directories
+                                                    handler   => \&handle_machinefolderchooser});
+    }
 }
 
 # Sets up the file chooser for selecting the autostart database directory
-sub show_autostartfolderchooser {
-    &show_remotefilechooser_window({title     => "Choose Autostart Database Folder on $endpoint",
-                                    basedir   => $gui{entryVBPrefsGenAutostartDBFolder}->get_text(),
-                                    filename  => '',
-                                    mode      => 'dir',
-                                    filter    => ' ^', # To only show directories
-                                    handler   => \&handle_autostartfolderchooser});
+{
+    my $startloc = $gui{entryVBPrefsGenAutostartDBFolder}->get_text();
+
+    sub show_autostartfolderchooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose Autostart Database Folder on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'dir',
+                                                    filter    => ' ^', # To only show directories
+                                                    handler   => \&handle_autostartfolderchooser});
+    }
 }
 
 # Sets up the file chooser for selecting the snapshot directory
-sub show_snapshotfolderchooser {
-    &show_remotefilechooser_window({title     => "Choose Snapshot Folder on $endpoint",
-                                    basedir   => $gui{entryEditGenSnapFolder}->get_text(),
-                                    filename  => '',
-                                    mode      => 'dir',
-                                    filter    => ' ^', # To only show directories
-                                    handler   => \&handle_snapshotfolderchooser});
+{
+    my $startloc = $gui{entryEditGenSnapFolder}->get_text();
+
+    sub show_snapshotfolderchooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose Snapshot Folder on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'dir',
+                                                    filter    => ' ^', # To only show directories
+                                                    handler   => \&handle_snapshotfolderchooser});
+    }
 }
 
-
 # Sets up the file chooser for selecting a shared folder
-sub show_sharedfolderchooser {
-    &show_remotefilechooser_window({title     => "Choose Shared Folder on $endpoint",
-                                    basedir   => $gui{entrySharedFolderPath}->get_text(),
-                                    filename  => '',
-                                    mode      => 'dir',
-                                    filter    => ' ^', # To only show directories
-                                    handler   => \&handle_sharedfolderchooser});
+{
+    my $startloc = $gui{entrySharedFolderPath}->get_text();
+
+    sub show_sharedfolderchooser {
+        $startloc = &show_remotefilechooser_window({title     => "Choose Shared Folder on $endpoint",
+                                                    basedir   => $startloc,
+                                                    filename  => '',
+                                                    mode      => 'dir',
+                                                    filter    => ' ^', # To only show directories
+                                                    handler   => \&handle_sharedfolderchooser});
+    }
 }
 
 sub show_remotefilechooser_window {
@@ -415,6 +443,7 @@ sub show_remotefilechooser_window {
         }
     }
 
+    return $gui{entryRemoteFileChooserLocation}->get_text();
 }
 
 sub refresh_remotefilechooser { &fill_list_remotefiles($gui{entryRemoteFileChooserLocation}->get_text(), $gui{entryRemoteFileChooserFilter}->get_text()); }
