@@ -1559,6 +1559,8 @@ sub onsel_list_shared {
         $gui{entryPrefsConnectionProfileURL}->set_text($selected{URL});
         $gui{entryPrefsConnectionProfileUsername}->set_text($selected{Username});
         $gui{entryPrefsConnectionProfilePassword}->set_text($selected{Password});
+        $gui{checkbuttonConnectionProfileAutoConnect}->set_active(1) if ($selected{Name} eq $prefs{AUTOCONNPROF});
+        $gui{checkbuttonConnectionProfileAutoConnect}->set_active(0) if ($selected{Name} ne $prefs{AUTOCONNPROF});
         $gui{buttonPrefsConnectionProfileDelete}->set_sensitive(1);
         $gui{tablePrefsProfile}->set_sensitive(1);
     }
@@ -1598,18 +1600,27 @@ sub onsel_list_shared {
         $gui{liststoreProfiles}->set_value($iter, 1, $gui{entryPrefsConnectionProfileURL}->get_text()) if ($iter);
     }
 
-        sub profile_username_change {
+    sub profile_username_change {
         my $model = $gui{treeviewConnectionProfiles}->get_model();
         my $iter = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
         $gui{liststoreProfiles}->set_value($iter, 2, $gui{entryPrefsConnectionProfileUsername}->get_text()) if ($iter);
     }
 
-        sub profile_password_change {
+    sub profile_password_change {
         my $model = $gui{treeviewConnectionProfiles}->get_model();
         my $iter = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
         $gui{liststoreProfiles}->set_value($iter, 3, $gui{entryPrefsConnectionProfilePassword}->get_text()) if ($iter);
     }
 
+    sub profile_autoconn_change {
+        my $state = $gui{checkbuttonConnectionProfileAutoConnect}->get_active();
+        if ($state) { $prefs{AUTOCONNPROF} = $gui{entryPrefsConnectionProfileName}->get_text(); }
+        else {
+            # Only clear it, if the profilename matches the auto connection name
+            $prefs{AUTOCONNPROF} = '' if ( $prefs{AUTOCONNPROF} eq $gui{entryPrefsConnectionProfileName}->get_text() );
+        }
+    }
+
 }
 
 
