@@ -24,7 +24,8 @@ Usage:
 USAGE
     exit 0;
 }
-elsif ($cmdopts{H}) { &show_dialog_connect('AUTO'); }
+elsif ($cmdopts{H}) { &show_dialog_connect('CMDAUTO'); } # Command line parameter based login
+elsif ($prefs{AUTOCONNPROF}) { &show_dialog_connect('PROFAUTO'); } # Profile based automatic login
 
 $0 = 'RemoteBox VirtualBox Client';
 Gtk2->main;
@@ -40,7 +41,7 @@ sub quit_remotebox {
     $gui{menuitemFloppy}->set_submenu($gui{menutmp1});
     $gui{menuitemDVD}->set_submenu($gui{menutmp2});
     $gui{menuitemUSB}->set_submenu($gui{menutmp3});
-    Gtk2->main_quit; # Supposedly deprecated but segfaults on newer systems if just exit is used
+    Gtk2->main_quit;
 }
 
 # Attempts to logon or fails with a dialog
@@ -110,13 +111,30 @@ sub show_dialog_connect {
 
     # Check if a command line automatic login has been requested. We do this here
     # to try an ensure that a cmdline login is as close as possible to a GUI login
-    if ($widget eq 'AUTO') {
+    if ($widget eq 'CMDAUTO') {
         $gui{entryConnectURL}->set_text($cmdopts{H});
         $gui{entryConnectUser}->set_text($cmdopts{u}) if ($cmdopts{u});
         $gui{entryConnectPassword}->set_text($cmdopts{p}) if ($cmdopts{p});
 
         $response = 'ok';
-        &addrow_log("Attempting automatic login to $endpoint");
+        &addrow_log("Attempting a command line based automatic login to $endpoint");
+    }
+    elsif ($widget eq 'PROFAUTO') {
+        my $model = $gui{treeviewConnectionProfiles}->get_model();
+        my $iter = $model->get_iter_first();
+
+        while($iter) {
+            my @row = $model->get($iter);
+            if ($row[0] eq $prefs{AUTOCONNPROF}) {
+                $gui{entryConnectURL}->set_text($row[1]);
+                $gui{entryConnectUser}->set_text($row[2]);
+                $gui{entryConnectPassword}->set_text($row[3]);
+                $response = 'ok';
+                &addrow_log("Attempting a profile based automatic login to $endpoint");
+                last;
+            }
+            $iter = $model->iter_next($iter);
+        }
     }
     else {
         # Normal GUI login
@@ -150,7 +168,7 @@ sub show_dialog_connect {
                 my $ISystemProperties = IVirtualBox_getSystemProperties($gui{websn});
                 &addrow_log("Logged onto $endpoint");
                 &addrow_log("Running VirtualBox $ver.");
-                &show_err_msg('vboxver', "\nDetected VirtualBox Version: $ver") if ($ver !~ m/^5.1/);
+                &show_err_msg('vboxver', "\nDetected VirtualBox Version: $ver") if ($ver !~ m/^5.2/);
                 &show_err_msg('noextensions') if (ISystemProperties_getDefaultVRDEExtPack($ISystemProperties) !~ m/Oracle VM VirtualBox Extension Pack/i);
                 &fill_list_guest();
                 &sens_connect(1);
@@ -207,7 +225,7 @@ sub show_dialog_log {
 sub show_dialog_exportappl {
     my $gref = &getsel_list_guest();
     my $vhost = &vhost();
-    my $fname = &rcatdir($$vhost{machinedir}, $$gref{Name} . '.ova');
+    my $fname = &rcatdir($$vhost{machinedir}, $$gref{Name});
     $gui{entryExportApplFile}->set_text($fname);
     $gui{entryExportApplName}->set_text($$gref{Name});
     $gui{textbufferExportApplDescription}->set_text(IMachine_getDescription($$gref{IMachine}));
@@ -246,8 +264,7 @@ sub show_dialog_exportappl {
             elsif (!$gui{entryExportApplName}->get_text()) { &show_err_msg('invalidname'); }
             else {
                 $gui{dialogExportAppl}->hide;
-                my $location = $gui{entryExportApplFile}->get_text();
-                $location .= '.ova' if ($location !~ m/.ovf$/i and $location !~ m/.ova$/i);
+                my $location = $gui{entryExportApplFile}->get_text() . &getsel_combo($gui{comboboxExportApplFormat}, 2);
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
 
                 foreach my $key (keys(%used_key_ids)) {
@@ -993,6 +1010,21 @@ sub keyboard_CAD {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
+# Attempts to release any pressed keys if the host and the guest become out of sync
+sub keyboard_releasekeys {
+    my ($widget) = @_;
+    my $gref = &getsel_list_guest();
+    my $sref = &get_session($$gref{IMachine});
+
+    if ($$sref{IMachine}) {
+        my $IKeyboard = IConsole_getKeyboard(ISession_getConsole($$sref{ISession}));
+        IKeyboard_releaseKeys($IKeyboard);
+        &addrow_log("Keyboard release keys to $$gref{Name}.");
+    }
+
+    ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
+}
+
 sub keyboard_send {
     my ($widget) = @_;
     my $gref = &getsel_list_guest();
