@@ -27,7 +27,8 @@ our %prefs = (RDPCLIENT         => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sou
               EXPANDDETUSB      => 1,
               EXPANDDETSHARE    => 1,
               EXPANDDETRUN      => 1,
-              EXPANDDETDESC     => 1);
+              EXPANDDETDESC     => 1,
+              AUTOCONNPROF      => '');
 
 # Import the current remotebox preferences
 sub rbprefs_get {
